==> gulp-nui-1.2.1.tgz: package/module.js <==
'use strict';

var path = require('path');
var fs = require('fs');
var replacepath = require('replacepath');

var unique = function(arr){
    var newarr = [];
    var temp = {};
    arr.forEach(function(val){
        if(!temp[val]){
            temp[val] = true
            newarr.push(val)
        }
    })
    return newarr
}

var isEmptyObject = function(obj){
    var name;
    for(name in obj){
        return false;
    }
    return true;
}

var inArray = function(str, arr){
    var len = arr.length;
    var i=0;
    for(i; i<len; i++){
        if(arr[i] == str){
            return true
        }
    }
    return false
}

module.exports = function(dirname, options){

    var cacheModules = {};
    var cacheStyles = {};

    function Module(id, name, deps){
        var mod = this;
        mod.id = id;
        mod.name = name;
        mod.deps = deps;
        mod.depmodules = {};
        mod.filename = mod.id.substr(mod.id.lastIndexOf('/')+1);
        mod.uri = mod.id.replace(new RegExp(mod.filename+'$'), '');
    }

    Module.prototype.load = function(){
        var mod = this;
        if(!/_module_\d+/.test(mod.name)){
            mod.url = mod.id + '.js';
            if(fs.existsSync(mod.url)){
                var buffer = fs.readFileSync(mod.url);
                var content = buffer.toString();
                mod.content = content.replace(/Nui.define\((['"][^'"]+['"]\s*,)?/, "Nui.define('"+ mod.name +"',")
                                     .replace(/renders\(\{((.|\s)*?)\}\)/g, function(str, code){
                	                     return 'renders(\''+code.replace(/'/g, '\\\'').replace(/([\r\n]+)/g, "'+''$1+'")+'\')'
                                     })
                var arrs = mod.getdeps();
                mod.deps = arrs[0];
                mod.styles = arrs[1];
            }
        }
        return mod.resolve()
    }

    Module.prototype.getdeps = function(){
        var mod = this;
        var content = mod.content;
        var deps = [];
        var styles = [];
        var depsMatchs = content.match(/Nui.define\((['"][^'"]+['"]\s*,)?\s*\[([^\[\]]+)\]/);
        var requireMatchs = content.match(/(require|extands|imports)\(['"][^'"]+['"]/g);
        if(depsMatchs){
            var match = depsMatchs[2].split(',');
            match.forEach(function(val, i){
                val = val.replace(/^\s+|\s+/g, '').replace(/['"]/g, '');
                if(!/^https?:\/\//.test(val) && !inArray(val, options.ignore)){
                    deps.push(val)
                }
            })
        }
        if(requireMatchs){
            requireMatchs.forEach(function(val, i){
                if(/^(require|extands)/.test(val)){
                    val = val.replace(/(require|extands)|[\('"]/g, '');
                    if(!/^https?:\/\//.test(val) && !inArray(val, options.ignore)){
                        deps.push(val)
                    }
                }
                else{
                    val = val.replace(/(imports)|[\('"]/g, '')
                    if(!/^https?:\/\//.test(val)){
                        styles.push(val)
                    }
                }
            })
        }
        return [unique(deps), unique(styles)]
    }

    Module.prototype.resolve = function(){
        var mod = this;
        if(isEmptyObject(mod.depmodules)){
            mod.deps.forEach(function(val, i){
                var module = Module.getModule(val, [], mod.uri);
                mod.depmodules[val] = module.load()
            })
        }
        return mod
    }

    Module.prototype.getContents = function(contents){
        var mod = this;
        if(!contents){
            contents = [];
        }
        contents.unshift(mod.content)
        if(mod.deps.length){
            for(var i in mod.depmodules){
                contents = mod.depmodules[i].getContents(contents)
            }
        }
        return contents
    }

    Module.prototype.loadstyles = function(styles){
        var mod = this;
        if(!styles){
            styles = [];
        }
        var arrs = [];
        if(mod.styles && mod.styles.length){
            mod.styles.forEach(function(val){
                arrs.push(Module.setId(val, mod.uri)[0]+'.css');
            })
        }
        styles = arrs.concat(styles);
        if(mod.deps.length){
            for(var i in mod.depmodules){
                styles = mod.depmodules[i].loadstyles(styles)
            }
        }

        return styles
    }

    Module.setPath = function(id){
        var pathMatch = id.match(/\{([^\{\}]+)\}/);
        if(pathMatch){
            var _path = options.paths[pathMatch[1]];
            if(_path){
                id = id.replace(pathMatch[0], _path).replace(/(\.(js|css))?(\?[\s\S]*)?$/g, '');
            }
        }
        return id
    }

    Module.setId = function(id, uri){
        var name = id.replace(/(\.(js|css))?(\?[\s\S]*)?$/g, '');
        id = Module.setPath(options.alias[name] || name);
        if(!(/^[A-Z]:/i).test(id)){
            id = uri + name;
        }
        return [replacepath(id), name]
    }

    Module.getModule = function(id, deps, uri){
        var arr = Module.setId(id, uri);
        id = arr[0];
        return cacheModules[id] || (cacheModules[id] = new Module(id, arr[1], deps))
    }

    Module.id = 0;

    Module.load = function(id, callback){
        var mod = Module.getModule('_module_'+Module.id++, [id], dirname);
        callback(mod.load())
    }

    Module.getStyles = function(arr){
        var arrs = [];
        arr.forEach(function(val){
            if(fs.existsSync(val)){
                var buffer = fs.readFileSync(val);
                var content = buffer.toString();
                arrs.push(content);
            }
        })
        return arrs
    }

    return Module
}

==> gulp-nui-1.2.2.tgz: package/module.js <==
'use strict';

var path = require('path');
var fs = require('fs');
var replacepath = require('replacepath');

var unique = function(arr){
    var newarr = [];
    var temp = {};
    arr.forEach(function(val){
        if(!temp[val]){
            temp[val] = true
            newarr.push(val)
        }
    })
    return newarr
}

var isEmptyObject = function(obj){
    var name;
    for(name in obj){
        return false;
    }
    return true;
}

var inArray = function(str, arr){
    var len = arr.length;
    var i=0;
    for(i; i<len; i++){
        if(arr[i] == str){
            return true
        }
    }
    return false
}

module.exports = function(dirname, options){

    var cacheModules = {};
    var cacheStyles = {};

    function Module(id, name, deps){
        var mod = this;
        mod.id = id;
        mod.name = name;
        mod.deps = deps;
        mod.depmodules = {};
        mod.filename = mod.id.substr(mod.id.lastIndexOf('/')+1);
        mod.uri = mod.id.replace(new RegExp(mod.filename+'$'), '');
    }

    Module.prototype.load = function(){
        var mod = this;
        if(!/_module_\d+/.test(mod.name)){
            mod.url = mod.id + '.js';
            if(fs.existsSync(mod.url)){
                var buffer = fs.readFileSync(mod.url);
                var content = buffer.toString();
                mod.content = content.replace(/Nui.define\((['"][^'"]+['"]\s*,)?/, "Nui.define('"+ mod.name +"',")
                                     .replace(/renders\(\{((.|\s)*?)\}\)/g, function(str, code){
                	                     return 'renders(\''+code.replace(/'/g, '\\\'').replace(/([\r\n]+)/g, "'+''$1+'").replace(/(\+')(\s+)/g, '$2$1')+'\')'
                                     })
                var arrs = mod.getdeps();
                mod.deps = arrs[0];
                mod.styles = arrs[1];
            }
        }
        return mod.resolve()
    }

    Module.prototype.getdeps = function(){
        var mod = this;
        var content = mod.content;
        var deps = [];
        var styles = [];
        var depsMatchs = content.match(/Nui.define\((['"][^'"]+['"]\s*,)?\s*\[([^\[\]]+)\]/);
        var requireMatchs = content.match(/(require|extands|imports)\(['"][^'"]+['"]/g);
        if(depsMatchs){
            var match = depsMatchs[2].split(',');
            match.forEach(function(val, i){
                val = val.replace(/^\s+|\s+/g, '').replace(/['"]/g, '');
                if(!/^https?:\/\//.test(val) && !inArray(val, options.ignore)){
                    deps.push(val)
                }
            })
        }
        if(requireMatchs){
            requireMatchs.forEach(function(val, i){
                if(/^(require|extands)/.test(val)){
                    val = val.replace(/(require|extands)|[\('"]/g, '');
                    if(!/^https?:\/\//.test(val) && !inArray(val, options.ignore)){
                        deps.push(val)
                    }
                }
                else{
                    val = val.replace(/(imports)|[\('"]/g, '')
                    if(!/^https?:\/\//.test(val)){
                        styles.push(val)
                    }
                }
            })
        }
        return [unique(deps), unique(styles)]
    }

    Module.prototype.resolve = function(){
        var mod = this;
        if(isEmptyObject(mod.depmodules)){
            mod.deps.forEach(function(val, i){
                var module = Module.getModule(val, [], mod.uri);
                mod.depmodules[val] = module.load()
            })
        }
        return mod
    }

    Module.prototype.getContents = function(contents){
        var mod = this;
        if(!contents){
            contents = [];
        }
        contents.unshift(mod.content)
        if(mod.deps.length){
            for(var i in mod.depmodules){
                contents = mod.depmodules[i].getContents(contents)
            }
        }
        return contents
    }

    Module.prototype.loadstyles = function(styles){
        var mod = this;
        if(!styles){
            styles = [];
        }
        var arrs = [];
        if(mod.styles && mod.styles.length){
            mod.styles.forEach(function(val){
                arrs.push(Module.setId(val, mod.uri)[0]+'.css');
            })
        }
        styles = arrs.concat(styles);
        if(mod.deps.length){
            for(var i in mod.depmodules){
                styles = mod.depmodules[i].loadstyles(styles)
            }
        }

        return styles
    }

    Module.setPath = function(id){
        var pathMatch = id.match(/\{([^\{\}]+)\}/);
        if(pathMatch){
            var _path = options.paths[pathMatch[1]];
            if(_path){
                id = id.replace(pathMatch[0], _path).replace(/(\.(js|css))?(\?[\s\S]*)?$/g, '');
            }
        }
        return id
    }

    Module.setId = function(id, uri){
        var name = id.replace(/(\.(js|css))?(\?[\s\S]*)?$/g, '');
        id = Module.setPath(options.alias[name] || name);
        if(!(/^[A-Z]:/i).test(id)){
            id = uri + name;
        }
        return [replacepath(id), name]
    }

    Module.getModule = function(id, deps, uri){
        var arr = Module.setId(id, uri);
        id = arr[0];
        return cacheModules[id] || (cacheModules[id] = new Module(id, arr[1], deps))
    }

    Module.id = 0;

    Module.load = function(id, callback){
        var mod = Module.getModule('_module_'+Module.id++, [id], dirname);
        callback(mod.load())
    }

    Module.getStyles = function(arr){
        var arrs = [];
        arr.forEach(function(val){
            if(fs.existsSync(val)){
                var buffer = fs.readFileSync(val);
                var content = buffer.toString();
                arrs.push(content);
            }
        })
        return arrs
    }

    return Module
}
